#define LANG_AM
#define LANG_AR
#define LANG_BR
#define LANG_CA
#define LANG_CN
#define LANG_CZ
#define LANG_DE
#define LANG_DK
#define LANG_EN
#define LANG_EO
#define LANG_ES
#define LANG_FA
#define LANG_FI
#define LANG_FR
#define LANG_GR
#define LANG_HR
#define LANG_HU
#define LANG_ID
#define LANG_IT
#define LANG_JE
#define LANG_JP
#define LANG_KE
#define LANG_KR
#define LANG_LT
#define LANG_LV
#define LANG_MK
#define LANG_NL
#define LANG_NO
#define LANG_PL
#define LANG_PT
#define LANG_RO
#define LANG_RU
#define LANG_SC
#define LANG_SI
#define LANG_SK
#define LANG_SR
#define LANG_SV
#define LANG_TR
#define LANG_TW
#define LANG_UA
#define LANG_VI
#define LANG_ZA
